GameType

Enum GameType 

pub enum GameType {
    Open,
    TwoVTwo,
    Adventure,
}
Game type for game pools within a lobby.

Each lobby can have multiple game pools, one per game type. Players wait in pools for matchmaking. Players join a game pool to find matches for that game type.

Variants



Open

Free-for-all open game (default)



TwoVTwo

2v2 team game



Adventure

Adventure/co-op mode