TimerVoteState

Enum TimerVoteState 

pub enum TimerVoteState {
    Idle,
    VoteInProgress {
        initiator_id: i64,
        voters: Vec<i64>,
        votes_needed: u32,
        expires_at: DateTime<Utc>,
    },
    TimerActive {
        expires_at: DateTime<Utc>,
        target_player_id: i64,
    },
    Cooldown {
        expires_at: DateTime<Utc>,
    },
    Disabled,
}
State of the timer vote system.

The timer vote allows players to collectively vote to start a turn timer on the current player. This prevents indefinite stalling.

Variants



Idle

No vote in progress, button is idle



VoteInProgress

Vote is in progress

Fields

initiator_id: i64

User ID of who initiated the vote

voters: Vec<i64>

User IDs of players who have voted yes

votes_needed: u32

Total votes needed to pass

expires_at: DateTime<Utc>

When the vote expires



TimerActive

Timer is actively counting down

Fields

expires_at: DateTime<Utc>

When the timer expires

target_player_id: i64

Target player ID (user ID)



Cooldown

Vote failed, in cooldown before another can start

Fields

expires_at: DateTime<Utc>

When the cooldown expires



Disabled

Feature disabled (not enough players)