pub enum GameType {
Open,
TwoVTwo,
Adventure,
}Expand description
Game type for game pools within a lobby.
Each lobby can have multiple game pools, one per game type. Players wait in pools for matchmaking. Players join a game pool to find matches for that game type.
Variants