pub enum TimerVoteState {
Idle,
VoteInProgress {
initiator_id: i64,
voters: Vec<i64>,
votes_needed: u32,
expires_at: DateTime<Utc>,
},
TimerActive {
expires_at: DateTime<Utc>,
target_player_id: i64,
},
Cooldown {
expires_at: DateTime<Utc>,
},
Disabled,
}Expand description
State of the timer vote system.
The timer vote allows players to collectively vote to start a turn timer on the current player. This prevents indefinite stalling.
Variants
Idle
No vote in progress, button is idle
VoteInProgress
Vote is in progress
Fields
TimerActive
Timer is actively counting down
Fields
Cooldown
Vote failed, in cooldown before another can start
Disabled
Feature disabled (not enough players)